==> prestashop_1.3.0.1.zip: prestashop/modules/paypal/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{paypal}prestashop>confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = ' El pedido de ';
$_MODULE['<{paypal}prestashop>confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = ' se ha guardado correctamente';
$_MODULE['<{paypal}prestashop>confirmation_15b0f8e55c6bdfc3d5fd0b6b3b6cb3ee'] = ' Ha seleccionado PayPal  como forma de pago';
$_MODULE['<{paypal}prestashop>confirmation_e6dc7945b557a1cd949bea92dd58963e'] = ' Le enviaremos el pedido lo antes posible';
$_MODULE['<{paypal}prestashop>confirmation_0db71da7150c27142eef9d22b843b4a9'] = ' Si tiene dudas o necesita información adicional, póngase en contacto con nuestro';
$_MODULE['<{paypal}prestashop>confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = ' servicio de atención al cliente ';
$_MODULE['<{paypal}prestashop>paypal_ad69e733ebae8d264bccaa38d68830e8'] = ' PayPal  ';
$_MODULE['<{paypal}prestashop>paypal_5960af4a01187dce25879df9a4c30df1'] = ' Aceptar pagos con PayPal  ';
$_MODULE['<{paypal}prestashop>paypal_fa214007826415a21a8456e3e09f999d'] = '¿Está seguro de que desea eliminar su configuración? ';
$_MODULE['<{paypal}prestashop>paypal_8edbd23e3562203eaf09db67ff656118'] = 'Actualmente está utilizando la dirección email PayPal por defecto, debe sustituirla por sus propia dirección';
$_MODULE['<{paypal}prestashop>paypal_fea16fa8c8fe3045f2107f66c07270a4'] = ' La dirección de correo electrónico de su cuenta Business PayPal  es necesaria. ';
$_MODULE['<{paypal}prestashop>paypal_eee1cda3b15829bb68c71304c5028609'] = ' PayPal  Business debe contenter una dirección de correo electrónico ';
$_MODULE['<{paypal}prestashop>paypal_f4d1ea475eaa85102e2b4e6d95da84bd'] = ' Confirmación ';
$_MODULE['<{paypal}prestashop>paypal_c888438d14855d7d96a2724ee9c306bd'] = ' Actualización de la configuración ';
$_MODULE['<{paypal}prestashop>paypal_6357d3551190ec7e79371a8570121d3a'] = 'Hay ';
$_MODULE['<{paypal}prestashop>paypal_4ce81305b7edb043d0a7a5c75cab17d0'] = 'Hay';
$_MODULE['<{paypal}prestashop>paypal_07213a0161f52846ab198be103b5ab43'] = ' errores ';
$_MODULE['<{paypal}prestashop>paypal_cb5e100e5a9a3e7f6d1fd97512215282'] = ' error ';
$_MODULE['<{paypal}prestashop>paypal_9518e6d551f7dc752b24af3629e849f9'] = ' Abrir una cuenta PayPal  ';
$_MODULE['<{paypal}prestashop>paypal_53453255a2713aeee8c4cf852eff9642'] = 'Si abre su cuenta PayPal pulsando la imagen que aparece a continuación, nos ayuda a mejorar la aplicación PrestaShop: ';
$_MODULE['<{paypal}prestashop>paypal_1569f6a31ff61f45c5ba13d7cab7e042'] = 'Este módulo le permite aceptar los pagos por PayPal  ';
$_MODULE['<{paypal}prestashop>paypal_3c4cb777e8df15388c680354569636b6'] = 'Si el cliente elige esta forma de pago, los fondos se abonarán automáticamente a su cuenta';
$_MODULE['<{paypal}prestashop>paypal_aaa1b7c0b32bdfdad61e1e2377695a5b'] = ' Debe configurar su cuenta PayPal antes de utilizar este módulo. ';
$_MODULE['<{paypal}prestashop>paypal_f4f70727dc34561dfde1a3c529b6205c'] = ' Configuración';
$_MODULE['<{paypal}prestashop>paypal_b709ed4067c3bd2272aaf9c3049159d8'] = 'Correo electrónico de su cuenta Business de PayPal ';
$_MODULE['<{paypal}prestashop>paypal_7e4ed5efc0f056eb2b36609af35177d3'] = 'Modo de prueba';
$_MODULE['<{paypal}prestashop>paypal_93cba07454f06a4a960172bbd6e2a435'] = ' Sí ';
$_MODULE['<{paypal}prestashop>paypal_bafd7322c6e97d25b6299b5d6fe8920b'] = ' No';
$_MODULE['<{paypal}prestashop>paypal_ee0174ba1fc039128d0a38074a7af945'] = ' URL de la imagen del banner ';
$_MODULE['<{paypal}prestashop>paypal_33887e395a8999be7ccc921fbcccf199'] = 'Es necesario alojar esta imagen en un servidor seguro para no mostrar advertencias. El tamaño no debe ser superior a 750x90 px. ';
$_MODULE['<{paypal}prestashop>paypal_b17f3f4dcf653a5776792498a9b44d6a'] = 'Actualización de la configuración';
$_MODULE['<{paypal}prestashop>paypal_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Información ';
$_MODULE['<{paypal}prestashop>paypal_8a4a5d8b35abe529250d8167c3035014'] = ' Para utilizar el módulo de PayPal, debe configurar su cuenta PayPal. Inicie sesión en su cuenta y siga las instrucciones.  ';
$_MODULE['<{paypal}prestashop>paypal_efeb369cccbd560588a756610865664c'] = 'En';
$_MODULE['<{paypal}prestashop>paypal_6176bbf80249aa464404925589a31fbe'] = 'Perfil > Preferencias de ventas > Preferencias de pago en el sitio Web';
$_MODULE['<{paypal}prestashop>paypal_dd7ecd17985702e86fadd19388a55713'] = 'configure: ';
$_MODULE['<{paypal}prestashop>paypal_6fb9e8044f1f4e90ec2faf0fc6828d8d'] = 'Retroceso automático';
$_MODULE['<{paypal}prestashop>paypal_d15305d7a4e34e02489c74a5ef542f36'] = 'Desactivado ';
$_MODULE['<{paypal}prestashop>paypal_e126a7f3f1a9cdd4b0b36513a1d84990'] = 'Transferencia de datos de pago';
$_MODULE['<{paypal}prestashop>paypal_01b6e20344b68835c5ed1ddedf20d531'] = 'en ';
$_MODULE['<{paypal}prestashop>paypal_dcce457d900813ecdd0b582ca9a46aba'] = 'Perfil > Preferencias de ventas > Cálculos de envío';
$_MODULE['<{paypal}prestashop>paypal_5fa07e3cff039e290957b1b2d57975a4'] = 'Pulse aquí para incluir en las transacciones los gastos de envío, de forma que reduzca los parámetros de perfil de transporte';
$_MODULE['<{paypal}prestashop>paypal_0eba834883c770311c90fa1aac44cd9d'] = 'Todas las divisas de PrestaShop deben configurarse Perfil > Información financiera > Saldo de divisas';
$_MODULE['<{paypal}prestashop>paypal_ea5ddaff9590d897631f00a7bcb035a2'] = 'Error de PayPal: (cuenta Business no válida o no definida) ';
$_MODULE['<{paypal}prestashop>paypal_e7ac6f09a936201890de4094b1ee4e50'] = 'Error de PayPal: (dirección o cliente no válidos)';
$_MODULE['<{paypal}prestashop>paypal_d89a00d4ba79c176bb0fc17f12d42a18'] = 'La clave de PayPal \'mc_gross\' no se ha especificado; no se puede controlar el importe pagado.';
$_MODULE['<{paypal}prestashop>paypal_202a2860b19003ce53966a8780bb448b'] = 'No se ha especificado la clave PayPal \'payment_status\'; no se puede verificar la validez del pago';
$_MODULE['<{paypal}prestashop>paypal_bd0e34e5be6447844e6f262d51f1a9dc'] = 'Pago: ';
$_MODULE['<{paypal}prestashop>paypal_3e2ec97cefea41ef807538dbdc069203'] = 'No se ha especificado la clave PayPal \'custom\', no se puede sustituir el carro';
$_MODULE['<{paypal}prestashop>paypal_760c3c2ccfadeee26c80c7b39462cf1d'] = 'No se ha especificado la clave PayPal   \'txn_id\', transacción no reconocida';
$_MODULE['<{paypal}prestashop>paypal_7faa8448e059fb97d60d4a4b15634d98'] = 'No se ha especificado la clave PayPal \'mc_currency\', divisa no reconocida';
$_MODULE['<{paypal}prestashop>paypal_e61f52d02b9f52fbe1fd41ed320e29c3'] = ' No se puede encontrar el carro de la compra';
$_MODULE['<{paypal}prestashop>paypal_0617900b1aff826081d07f5a3e2e7cd0'] = 'Ya se ha procesado el pedido';
$_MODULE['<{paypal}prestashop>paypal_f5209b3301a46f3057ffbf34d903e205'] = 'Id. de la transacción de PayPal: ';
$_MODULE['<{paypal}prestashop>paypal_7b19e875ff64b09d80ee05dcc84b9975'] = 'No se ha podido verificar la transacción de PayPal. ';
$_MODULE['<{paypal}prestashop>paypal_20dfea1a472e5be3f15f6b5f36ca335c'] = ' Error de conexión con el servidor de PayPal. ';
$_MODULE['<{paypal}prestashop>paypal_76ee8dc73701e846f7bccdf98dae079b'] = 'No hay protocolos de comunicación disponibles. ';
$_MODULE['<{paypal}prestashop>paypal_8358ec19f397d4cdd632688d4f79e535'] = 'Error de verificación  (protocolo fsockopen) . Retroceso: ';
$_MODULE['<{paypal}prestashop>paypal_eca77e208634d52703b07672abbf16ec'] = 'Error de verificación  (protocolo cURL) . Retroceso: ';
$_MODULE['<{paypal}prestashop>paypal_f7799c2ded739cf3c3e9babffc5f315b'] = 'Error de conexión con protocolo cURL. ';
$_MODULE['<{paypal}prestashop>paypal_dac2693baa5c5c9a5318609ed81c4f2a'] = 'Pagar con PayPal';
$_MODULE['<{paypal}prestashop>paypal_dae3b417a0fc4a49e851ce55d6d49551'] = 'Mi carrito';
$_MODULE['<{paypal}prestashop>paypal_1e70c590fa951ed2ec1411b84aa0197e'] = 'Volver a';

==> prestashop_1.3.0.2.zip: prestashop/modules/paypal/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{paypal}prestashop>confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = ' El pedido de ';
$_MODULE['<{paypal}prestashop>confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = ' se ha guardado correctamente';
$_MODULE['<{paypal}prestashop>confirmation_15b0f8e55c6bdfc3d5fd0b6b3b6cb3ee'] = ' Ha seleccionado PayPal  como forma de pago';
$_MODULE['<{paypal}prestashop>confirmation_e6dc7945b557a1cd949bea92dd58963e'] = ' Le enviaremos el pedido lo antes posible';
$_MODULE['<{paypal}prestashop>confirmation_0db71da7150c27142eef9d22b843b4a9'] = ' Si tiene dudas o necesita información adicional, póngase en contacto con nuestro';
$_MODULE['<{paypal}prestashop>confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = ' servicio de atención al cliente ';
$_MODULE['<{paypal}prestashop>paypal_ad69e733ebae8d264bccaa38d68830e8'] = ' PayPal  ';
$_MODULE['<{paypal}prestashop>paypal_5960af4a01187dce25879df9a4c30df1'] = ' Aceptar pagos con PayPal  ';
$_MODULE['<{paypal}prestashop>paypal_fa214007826415a21a8456e3e09f999d'] = '¿Está seguro de que desea eliminar su configuración? ';
$_MODULE['<{paypal}prestashop>paypal_8edbd23e3562203eaf09db67ff656118'] = 'Actualmente está utilizando la dirección email PayPal por defecto, debe sustituirla por sus propia dirección';
$_MODULE['<{paypal}prestashop>paypal_fea16fa8c8fe3045f2107f66c07270a4'] = ' La dirección de correo electrónico de su cuenta Business PayPal  es necesaria. ';
$_MODULE['<{paypal}prestashop>paypal_eee1cda3b15829bb68c71304c5028609'] = ' PayPal  Business debe contenter una dirección de correo electrónico ';
$_MODULE['<{paypal}prestashop>paypal_f4d1ea475eaa85102e2b4e6d95da84bd'] = ' Confirmación ';
$_MODULE['<{paypal}prestashop>paypal_c888438d14855d7d96a2724ee9c306bd'] = ' Actualización de la configuración ';
$_MODULE['<{paypal}prestashop>paypal_6357d3551190ec7e79371a8570121d3a'] = 'Hay ';
$_MODULE['<{paypal}prestashop>paypal_4ce81305b7edb043d0a7a5c75cab17d0'] = 'Hay';
$_MODULE['<{paypal}prestashop>paypal_07213a0161f52846ab198be103b5ab43'] = ' errores ';
$_MODULE['<{paypal}prestashop>paypal_cb5e100e5a9a3e7f6d1fd97512215282'] = ' error ';
$_MODULE['<{paypal}prestashop>paypal_9518e6d551f7dc752b24af3629e849f9'] = ' Abrir una cuenta PayPal  ';
$_MODULE['<{paypal}prestashop>paypal_53453255a2713aeee8c4cf852eff9642'] = 'Si abre su cuenta PayPal pulsando la imagen que aparece a continuación, nos ayuda a mejorar la aplicación PrestaShop: ';
$_MODULE['<{paypal}prestashop>paypal_1569f6a31ff61f45c5ba13d7cab7e042'] = 'Este módulo le permite aceptar los pagos por PayPal  ';
$_MODULE['<{paypal}prestashop>paypal_3c4cb777e8df15388c680354569636b6'] = 'Si el cliente elige esta forma de pago, los fondos se abonarán automáticamente a su cuenta';
$_MODULE['<{paypal}prestashop>paypal_aaa1b7c0b32bdfdad61e1e2377695a5b'] = ' Debe configurar su cuenta PayPal antes de utilizar este módulo. ';
$_MODULE['<{paypal}prestashop>paypal_f4f70727dc34561dfde1a3c529b6205c'] = ' Configuración';
$_MODULE['<{paypal}prestashop>paypal_b709ed4067c3bd2272aaf9c3049159d8'] = 'Correo electrónico de su cuenta Business de PayPal ';
$_MODULE['<{paypal}prestashop>paypal_93cba07454f06a4a960172bbd6e2a435'] = ' Sí ';
$_MODULE['<{paypal}prestashop>paypal_bafd7322c6e97d25b6299b5d6fe8920b'] = ' No';
$_MODULE['<{paypal}prestashop>paypal_ee0174ba1fc039128d0a38074a7af945'] = ' URL de la imagen del banner ';
$_MODULE['<{paypal}prestashop>paypal_33887e395a8999be7ccc921fbcccf199'] = 'Es necesario alojar esta imagen en un servidor seguro para no mostrar advertencias. El tamaño no debe ser superior a 750x90 px. ';
$_MODULE['<{paypal}prestashop>paypal_b17f3f4dcf653a5776792498a9b44d6a'] = 'Actualización de la configuración';
$_MODULE['<{paypal}prestashop>paypal_a82be0f551b8708bc08eb33cd9ded0cf'] = 'Información ';
$_MODULE['<{paypal}prestashop>paypal_8a4a5d8b35abe529250d8167c3035014'] = ' Para utilizar el módulo de PayPal, debe configurar su cuenta PayPal. Inicie sesión en su cuenta y siga las instrucciones.  ';
$_MODULE['<{paypal}prestashop>paypal_efeb369cccbd560588a756610865664c'] = 'En';
$_MODULE['<{paypal}prestashop>paypal_dd7ecd17985702e86fadd19388a55713'] = 'configure: ';
$_MODULE['<{paypal}prestashop>paypal_6fb9e8044f1f4e90ec2faf0fc6828d8d'] = 'Retroceso automático';
$_MODULE['<{paypal}prestashop>paypal_d15305d7a4e34e02489c74a5ef542f36'] = 'Desactivado ';
$_MODULE['<{paypal}prestashop>paypal_e126a7f3f1a9cdd4b0b36513a1d84990'] = 'Transferencia de datos de pago';
$_MODULE['<{paypal}prestashop>paypal_01b6e20344b68835c5ed1ddedf20d531'] = 'en ';
$_MODULE['<{paypal}prestashop>paypal_5fa07e3cff039e290957b1b2d57975a4'] = 'Pulse aquí para incluir en las transacciones los gastos de envío, de forma que reduzca los parámetros de perfil de transporte';
$_MODULE['<{paypal}prestashop>paypal_0eba834883c770311c90fa1aac44cd9d'] = 'Todas las divisas de PrestaShop deben configurarse Perfil > Información financiera > Saldo de divisas';
$_MODULE['<{paypal}prestashop>paypal_d89a00d4ba79c176bb0fc17f12d42a18'] = 'La clave de PayPal \'mc_gross\' no se ha especificado; no se puede controlar el importe pagado.';
$_MODULE['<{paypal}prestashop>paypal_202a2860b19003ce53966a8780bb448b'] = 'No se ha especificado la clave PayPal \'payment_status\'; no se puede verificar la validez del pago';
$_MODULE['<{paypal}prestashop>paypal_bd0e34e5be6447844e6f262d51f1a9dc'] = 'Pago: ';
$_MODULE['<{paypal}prestashop>paypal_3e2ec97cefea41ef807538dbdc069203'] = 'No se ha especificado la clave PayPal \'custom\', no se puede sustituir el carro';
$_MODULE['<{paypal}prestashop>paypal_760c3c2ccfadeee26c80c7b39462cf1d'] = 'No se ha especificado la clave PayPal   \'txn_id\', transacción no reconocida';
$_MODULE['<{paypal}prestashop>paypal_7faa8448e059fb97d60d4a4b15634d98'] = 'No se ha especificado la clave PayPal \'mc_currency\', divisa no reconocida';
$_MODULE['<{paypal}prestashop>paypal_e61f52d02b9f52fbe1fd41ed320e29c3'] = ' No se puede encontrar el carro de la compra';
$_MODULE['<{paypal}prestashop>paypal_0617900b1aff826081d07f5a3e2e7cd0'] = 'Ya se ha procesado el pedido';
$_MODULE['<{paypal}prestashop>paypal_f5209b3301a46f3057ffbf34d903e205'] = 'Id. de la transacción de PayPal: ';
$_MODULE['<{paypal}prestashop>paypal_7b19e875ff64b09d80ee05dcc84b9975'] = 'No se ha podido verificar la transacción de PayPal. ';
$_MODULE['<{paypal}prestashop>paypal_20dfea1a472e5be3f15f6b5f36ca335c'] = ' Error de conexión con el servidor de PayPal. ';
$_MODULE['<{paypal}prestashop>paypal_76ee8dc73701e846f7bccdf98dae079b'] = 'No hay protocolos de comunicación disponibles. ';
$_MODULE['<{paypal}prestashop>paypal_8358ec19f397d4cdd632688d4f79e535'] = 'Error de verificación  (protocolo fsockopen) . Retroceso: ';
$_MODULE['<{paypal}prestashop>paypal_eca77e208634d52703b07672abbf16ec'] = 'Error de verificación  (protocolo cURL) . Retroceso: ';
$_MODULE['<{paypal}prestashop>paypal_f7799c2ded739cf3c3e9babffc5f315b'] = 'Error de conexión con protocolo cURL. ';
$_MODULE['<{paypal}prestashop>paypal_dac2693baa5c5c9a5318609ed81c4f2a'] = 'Pagar con PayPal';
$_MODULE['<{paypal}prestashop>redirect_ea5ddaff9590d897631f00a7bcb035a2'] = 'Error Paypal: (invalid or undefined business account email)';
$_MODULE['<{paypal}prestashop>redirect_e7ac6f09a936201890de4094b1ee4e50'] = 'Error Paypal: (invalid address or customer)';
$_MODULE['<{paypal}prestashop>redirect_dae3b417a0fc4a49e851ce55d6d49551'] = 'Carro';
